@@ -1,32 +1,21 @@
 """
 Defines the project's API endpoints.
 """
-
-from functools import wraps
 from typing import Any, Mapping
 
-from flask import Blueprint, redirect, request, url_for
+import psycopg2
+from flask import Blueprint, request
 from flask_admin.base import render_template
 from jinja2 import Template
 from werkzeug.routing import Map, Rule
 
-from api_reflector import actions, models, rules_engine
-from api_reflector.auth import is_authorized
+from api_reflector import db, models, rules_engine
+from api_reflector.auth import requires_auth
+from api_reflector.endpoint import ensure_leading_slash
 from api_reflector.reporting import get_logger
 
 api = Blueprint("api", __name__)
-log = get_logger("api")
-
-
-def ensure_leading_slash(path: str) -> str:
-    """
-    Ensures that the given path has a leading slash.
-    This is needed as mock paths are stored in the database with a leading slash, but flask passes the path parameter
-    without one.
-    """
-    if path[0] != "/":
-        return "/" + path
-    return path
+log = get_logger(__name__)
 
 
 def match_endpoint(path: str) -> tuple[models.Endpoint, Mapping[str, Any]]:
@@ -42,45 +31,32 @@ def match_endpoint(path: str) -> tuple[models.Endpoint, Mapping[str, Any]]:
         models.Endpoint.method == request.method.upper()
     ).all()
 
-    urls = Map([Rule(endpoint.path, endpoint=endpoint, methods=[request.method]) for endpoint in endpoints]).bind(
-        "localhost"
-    )
+    rules = [Rule(endpoint.path, endpoint=endpoint, methods=[request.method]) for endpoint in endpoints]
+    urls = Map(rules).bind("localhost")
 
     # we're disabling mypy here because you're supposed to get strings back from `match`, not full endpoint objects.
     return urls.match(path, method=request.method)  # type: ignore
 
 
-def execute_response_actions(response: models.Response) -> None:
-    """
-    Executes all response actions for the given response.
-    """
-    log.debug(f"Executing actions for response: {response}")
-    for action in response.actions:
-        log.debug(f"Executing action: {action}")
-        actions.action_executors[action.action](*action.arguments)
-
-
-def requires_auth(view_function):
-    """
-    Flask view function decorator that ensures that the user is authenticated.
-    The user is redirected to the Azure login flow if they are not already authenticated.
-    """
-
-    @wraps(view_function)
-    def decorator(*args, **kwargs):
-        if not is_authorized():
-            return redirect(url_for("azure.login"))
-        return view_function(*args, **kwargs)
-
-    return decorator
-
-
 @api.route("/healthz")
+@api.route("/livez")
 def healthz() -> tuple[Any, int]:
     """
-    Returns a 200 OK response.
+    Returns a 204 OK response.
     """
-    return "OK", 200
+    return "", 204
+
+
+@api.route("/readyz")
+def readyz() -> tuple[Any, int]:
+    """
+    Returns a 204 OK response if services are accessible, 500 otherwise.
+    """
+    try:
+        db.sqla.engine.execute("SELECT 1").fetchone()
+    except psycopg2.Error as ex:
+        return f"Database is not accessible.\nException:\n\n{ex}", 500
+    return "", 204
 
 
 @api.route("/")
@@ -89,8 +65,8 @@ def home() -> tuple[Any, int]:
     """
     Renders the home page.
     """
-    endpoints = models.Endpoint.query.all()
-    tags = models.Tag.query.all()
+    endpoints = models.Endpoint.query.order_by(models.Endpoint.name).all()
+    tags = models.Tag.query.order_by(models.Tag.name).all()
     return render_template("home.html", endpoints=endpoints, tags=tags), 200
 
 
@@ -125,19 +101,19 @@ def mock(path: str) -> tuple[Any, int]:
     ]
 
     if request.is_json:
-        json = request.json  # type: Any
+        req_json = request.json  # type: Any
     else:
-        json = {}
+        req_json = {}
 
-    templateable_request = rules_engine.TemplatableRequest(params=params, json=json)
+    templateable_request = rules_engine.TemplatableRequest(params=params, json=req_json)
     response = rules_engine.find_best_response(templateable_request, response_rules)
 
-    execute_response_actions(response)
-
     content = Template(response.content).render(
         {
             "request": templateable_request,
         }
     )
 
+    response.execute_actions(req_json, content)
+
     return content, response.status_code
