@@ -19,6 +19,9 @@ class Settings(BaseSettings):
     log_json: bool = True
     log_level: str = "info"
 
+    environment: str = "production"
+    sentry_dsn: Optional[str]
+
     trace_query_descriptions: bool = False
 
     @validator("azure_client_id", "azure_client_secret", "azure_tenant")
